@@ -88,8 +88,8 @@ public class VLCApplication extends Application {
 
     @Override
     public void onCreate() {
-        super.onCreate();
         instance = this;
+        super.onCreate();
         mSettings = PreferenceManager.getDefaultSharedPreferences(this);
 
         setLocale();
@@ -115,6 +115,8 @@ public class VLCApplication extends Application {
         });
         if (sActivityCbListener != null)
             registerActivityLifecycleCallbacks(sActivityCbListener);
+        else
+            ExternalMonitor.register(instance);
     }
 
     @Override
@@ -280,22 +282,23 @@ public class VLCApplication extends Application {
     }
 
     /**
-     * Check if Oreo will allow background service
-     * @return false if service needs to immediatly declare itself foreground.
+     * Check if application is currently displayed
+     * @return true if an activity is displayed, false if app is in background.
      */
     public static boolean isForeground() {
-        return sActivityCbListener == null || sActivitiesCount > 0;
+        return sActivitiesCount > 0;
     }
 
     private static int sActivitiesCount = 0;
-    private static ActivityLifecycleCallbacks sActivityCbListener = AndroidUtil.isOOrLater ? new ActivityLifecycleCallbacks() {
+    private static ActivityLifecycleCallbacks sActivityCbListener = AndroidUtil.isICSOrLater ? new ActivityLifecycleCallbacks() {
         @Override
-        public void onActivityCreated(Activity activity, Bundle savedInstanceState) {
-            ++sActivitiesCount;
-        }
+        public void onActivityCreated(Activity activity, Bundle savedInstanceState) {}
 
         @Override
-        public void onActivityStarted(Activity activity) {}
+        public void onActivityStarted(Activity activity) {
+            if (++sActivitiesCount == 1)
+                ExternalMonitor.register(instance);
+        }
 
         @Override
         public void onActivityResumed(Activity activity) {}
@@ -304,14 +307,15 @@ public class VLCApplication extends Application {
         public void onActivityPaused(Activity activity) {}
 
         @Override
-        public void onActivityStopped(Activity activity) {}
+        public void onActivityStopped(Activity activity) {
+            if (--sActivitiesCount == 0)
+                ExternalMonitor.unregister(instance);
+        }
 
         @Override
         public void onActivitySaveInstanceState(Activity activity, Bundle outState) {}
 
         @Override
-        public void onActivityDestroyed(Activity activity) {
-            --sActivitiesCount;
-        }
+        public void onActivityDestroyed(Activity activity) {}
     } : null;
 }
