@@ -372,8 +372,10 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
      * Update views visibility and emptiness info
      */
     protected void updateEmptyView() {
+        if (mSwipeRefreshLayout == null)
+            return;
         if (mAdapter.isEmpty()) {
-            if (mSwipeRefreshLayout == null || mSwipeRefreshLayout.isRefreshing()) {
+            if (mSwipeRefreshLayout.isRefreshing()) {
                 mEmptyView.setText(R.string.loading);
                 mEmptyView.setVisibility(View.VISIBLE);
                 mRecyclerView.setVisibility(View.GONE);
@@ -498,11 +500,11 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
     }
 
     protected void setContextMenuItems(Menu menu, int position) {
-        MediaWrapper mw = (MediaWrapper) mAdapter.getItem(position);
-        int type = mw.getType();
+        final MediaWrapper mw = (MediaWrapper) mAdapter.getItem(position);
+        final int type = mw.getType();
         boolean canWrite = this instanceof FileBrowserFragment && FileUtils.canWrite(mw.getUri().getPath());
         if (type == MediaWrapper.TYPE_DIR) {
-            boolean isEmpty = Util.isListEmpty(mFoldersContentLists.get(position));
+            final boolean isEmpty = Util.isListEmpty(mFoldersContentLists.get(mw));
 //                if (canWrite) {
 //                    boolean nomedia = new File(mw.getLocation() + "/.nomedia").exists();
 //                    menu.findItem(R.id.directory_view_hide_media).setVisible(!nomedia);
@@ -788,7 +790,7 @@ public abstract class BaseBrowserFragment extends SortableFragment<BaseBrowserAd
     }
 
     public void restoreList() {
-        if (mAdapter != null)
+        if (mAdapter != null && mEmptyView != null)
             mAdapter.restoreList();
     }
     public void setSearchVisibility(boolean visible) {
